durationtools.rewrite_rational_under_new_tempo
==============================================

.. autofunction:: abjad.tools.durationtools.rewrite_rational_under_new_tempo.rewrite_rational_under_new_tempo
